@@ -17,7 +17,7 @@ Usage::
 
     list_servers_paginator: ListServersPaginator = client.get_paginator("list_servers")
 """
-from mypy_boto3_transfer.client import TransferClient as Client, TransferClient
+from mypy_boto3_transfer.client import TransferClient, TransferClient as Client
 from mypy_boto3_transfer.paginator import ListServersPaginator
 
 
