@@ -67,12 +67,14 @@ _RequiredDescribedServerTypeDef = TypedDict("_RequiredDescribedServerTypeDef", {
 _OptionalDescribedServerTypeDef = TypedDict(
     "_OptionalDescribedServerTypeDef",
     {
+        "Certificate": str,
         "EndpointDetails": EndpointDetailsTypeDef,
         "EndpointType": Literal["PUBLIC", "VPC", "VPC_ENDPOINT"],
         "HostKeyFingerprint": str,
         "IdentityProviderDetails": IdentityProviderDetailsTypeDef,
         "IdentityProviderType": Literal["SERVICE_MANAGED", "API_GATEWAY"],
         "LoggingRole": str,
+        "Protocols": List[Literal["SFTP", "FTP", "FTPS"]],
         "ServerId": str,
         "State": Literal[
             "OFFLINE", "ONLINE", "STARTING", "STOPPING", "START_FAILED", "STOP_FAILED"
